.. earthquakepy documentation master file, created by
   sphinx-quickstart on Sun Mar 27 11:38:36 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to earthquakepy's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage


earthquakepy
============

A python library for earthquake engineers.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
